# #!/usr/bin/env python
# # -*- coding: utf-8 -*-

from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from SuPyMode.supermode import SuperMode

from typing import NoReturn
from SuPyMode.representation.base import InheritFromSuperMode, BaseSingleModePlot
import matplotlib.pyplot as plt


class Index(InheritFromSuperMode, BaseSingleModePlot):
    """
    Represents the effective refractive index of a mode derived from a supermode in optical fiber simulations.

    This class extends from `InheritFromSuperMode` for accessing supermode-related data and `BaseSingleModePlot`
    for plotting functionalities tailored to visualize the effective refractive index.

    Class Attributes:
        plot_style (dict): A dictionary defining the default style settings for plots generated by this class.
    """

    def __init__(self, parent_supermode: SuperMode):
        """
        Initializes an Index object with a reference to a parent supermode.

        Args:
            parent_supermode (SuperMode): The parent supermode object that provides the base mode data.
        """
        self.parent_supermode = parent_supermode
        self.data = self.parent_supermode.binding.get_index()

    def _dress_ax(self, ax: plt.Axes) -> NoReturn:
        ax.set_xlabel('Inverse taper ratio')
        ax.set_ylabel('Effective refraction index')
        ax.set_ylim([1.44, 1.455])

# -
